# Filename:     tb_microprocessor.do
# Filetype:     Modelsim Script File
# Date:         5 may 2014
# Update:       -
# Description:  Script File For Automatic Simulation
# Author:       J. op den Brouw
# State:        Demo
# Error:        -
# Version:      1.1
# Copyright:    (c)2014, De Haagse Hogeschool

# Transcript on
transcript on

# Recreate work library
if {[file exists rtl_work]} {
	vdel -lib rtl_work -all
}
vlib rtl_work
vmap work rtl_work

# Find out if we're started through Quartus or by hand
# (or by using an exec in the Tcl window in Quartus).
# Quartus has the annoying property that it will start
# Modelsim from a directory called "simulation/modelsim".
# The design and the testbench are located in the project
# root, so we've to compensate for that.
if [ string match "*simulation/modelsim" [pwd] ] { 
	set prefix "../../"
	puts "Running Modelsim from Quartus..."
} else {
	set prefix ""
	puts "Running Modelsim..."
}

# Compile the VHDL description and testbench,
# please note that the design and its testbench are located
# in the project root, but the simulator start in directory
# <project_root>/simulation/modelsim, so we have to compensate
# for that.
vcom -93 -work work ${prefix}microprocessor.vhd
vcom -93 -work work ${prefix}tb_microprocessor.vhd

vsim -t 1ns -L rtl_work -L work -voptargs="+acc"  tb_microprocessor

# Log all signals in the design, good if the number
# of signals is small.
add log -r *

# Add all toplevel signals
# Add a number of signals of the simulated design
add wave -divider "Inputs/Outputs"
add wave            -label clk clk
add wave            -label areset areset
add wave -radix hex -label input input
add wave -radix hex -label output output
add wave -divider "Internals - Registers"
add wave -radix hex -label reg0 dut/reg0
add wave -radix hex -label reg1 dut/reg1
add wave -radix hex -label reg2 dut/reg2
add wave -radix hex -label reg3 dut/reg3
add wave -divider "Internals - Mux/demux"
add wave -radix hex -label muxaout dut/muxaout
add wave -radix hex -label muxbout dut/muxbout
add wave            -label enr0 dut/enr0
add wave            -label enr1 dut/enr1
add wave            -label enr2 dut/enr2
add wave            -label enr3 dut/enr3
add wave -divider "Internals - ALU/flags"
add wave -radix hex -label acode dut/acode
add wave -radix hex -label alu_resulta dut/alu_result
add wave            -label cflag dut/cflag
add wave            -label cupdate dut/cupdate
add wave            -label zflag dut/zflag
add wave            -label zupdate dut/zupdate
add wave -divider "Internals - PC"
add wave            -label ldpc dut/ldpc
add wave -radix hex -label pc dut/pc
add wave -divider "Internals - ROM"
add wave -radix hex -label sela dut/sela
add wave -radix hex -label selb dut/selb
add wave -radix hex -label seld dut/seld
add wave -radix hex -label acode dut/acode
add wave -radix hex -label const dut/const
add wave            -label en_d dut/en_d
add wave -radix hex -label jcode dut/jcode
add wave -radix hex -label address dut/address

# Open Structure, Signals (waveform) and List window
view structure
#view list
view signals

# Run simulation for 1000 ns
run 900 ns

# Fill up the waveform in the window
wave zoom full