-- Filename:     tb_microprocessor.vhd
-- Filetype:     VHDL code
-- Date:         23 may 2012
-- Update:       04 may 2014
-- Description:  VHDL testbench code
-- Author:       J. op den Brouw
-- State:        demo
-- Error:        -
-- Version:      1.1
-- Copyright:    (c)2014, De Haagse Hogeschool
--

library ieee;                                               
use ieee.std_logic_1164.all;  
use ieee.numeric_std.all;

-- Empty entity						 
entity tb_microprocessor is
end tb_microprocessor;

architecture testbench of tb_microprocessor is
-- The clock period and delay
constant Tperiod : time := 10 ns;
constant small_delay : time := 1 ns;

-- The signals to monitor...
signal clk : std_logic;
signal input : unsigned(7 downto 0);
signal output : unsigned(7 downto 0);
signal areset : std_logic;

-- The component to test...
component microprocessor
    port (clk    : in std_logic;
          areset : in std_logic;
          input  : in unsigned(7 downto 0);
          output : out unsigned(7 downto 0)
         );
end component;

begin

    -- Instantiate a device...
    dut : microprocessor
    port map (clk => clk, areset => areset, input => input, output => output);
 
    -- The clock generator.
    clockgen: process is
    begin
        clk <= '0';
        wait for Tperiod/2;
        clk <= '1';
        wait for Tperiod/2;
    end process clockgen;

    -- The data generator, including reset
    datagen: process is
    begin

        -- Some data on the input
        input <= X"A5";

        -- Assert reset
        areset <= '1';
        wait for 2*Tperiod;

        -- Negate reset 
        areset <= '0';
        wait for 2*Tperiod;
        wait until clk = '1';
        wait for small_delay;

        -- Wait for program to finish
        --for i in 1 to 29 loop
        --    wait until clk = '1';
        --end loop;
    
        wait;
    end process datagen;

end architecture testbench;
